@@ -1,22 +1,24 @@
-from unittest import TestCase
-from unittest import mock
-from staticsite.cmd.command import SiteCommand
-from staticsite.cmd.build import Build
-from . import utils as test_utils
+from __future__ import annotations
+
 import os
+from unittest import TestCase, mock
+
+from staticsite.cmd.command import SiteCommand
+
+from . import utils as test_utils
 
 
-class TestBuildSettings(TestCase):
+class TestBuildSettings(test_utils.MockSiteTestMixin, TestCase):
     """
     Test settings after command line parsing
     """
     def test_defaults(self):
-        with test_utils.workdir() as root:
-            with mock.patch("os.getcwd", return_value=root):
+        with self.site(test_utils.MockSite({}, auto_load_site=False)) as mocksite:
+            with mock.patch("os.getcwd", return_value=mocksite.root):
                 args = test_utils.Args()
                 cmd = SiteCommand(args)
             settings = cmd.settings
-            self.assertEqual(settings.PROJECT_ROOT, root)
+            self.assertEqual(settings.PROJECT_ROOT, mocksite.root)
             self.assertEqual(settings.SITE_ROOT, "/")
             self.assertIsNone(settings.SITE_NAME)
             self.assertEqual(settings.ARCHETYPES, "archetypes")
@@ -32,12 +34,12 @@ class TestBuildSettings(TestCase):
         files = {
             "settings.py": "SITE_NAME = 'Test Site'\n",
         }
-        with test_utils.workdir(files) as root:
-            with mock.patch("os.getcwd", return_value=root):
+        with self.site(test_utils.MockSite(files, auto_load_site=False)) as mocksite:
+            with mock.patch("os.getcwd", return_value=mocksite.root):
                 args = test_utils.Args()
                 cmd = SiteCommand(args)
             settings = cmd.settings
-            self.assertEqual(settings.PROJECT_ROOT, root)
+            self.assertEqual(settings.PROJECT_ROOT, mocksite.root)
             self.assertEqual(settings.SITE_ROOT, "/")
             self.assertEqual(settings.SITE_NAME, "Test Site")
             self.assertEqual(settings.ARCHETYPES, "archetypes")
@@ -53,12 +55,12 @@ class TestBuildSettings(TestCase):
         files = {
             ".staticsite.py": "SITE_NAME = 'Test Site'\n",
         }
-        with test_utils.workdir(files) as root:
-            with mock.patch("os.getcwd", return_value=root):
+        with self.site(test_utils.MockSite(files, auto_load_site=False)) as mocksite:
+            with mock.patch("os.getcwd", return_value=mocksite.root):
                 args = test_utils.Args()
                 cmd = SiteCommand(args)
             settings = cmd.settings
-            self.assertEqual(settings.PROJECT_ROOT, root)
+            self.assertEqual(settings.PROJECT_ROOT, mocksite.root)
             self.assertEqual(settings.SITE_ROOT, "/")
             self.assertEqual(settings.SITE_NAME, "Test Site")
             self.assertEqual(settings.ARCHETYPES, "archetypes")
@@ -71,32 +73,28 @@ class TestBuildSettings(TestCase):
             self.assertTrue(settings.CACHE_REBUILDS)
 
 
-class TestExampleProject(TestCase):
+class TestExampleProject(test_utils.SiteTestMixin, TestCase):
+    site_name = "demo"
+
     def test_settings(self):
-        with test_utils.example_site_dir() as root:
-            args = test_utils.Args(project=root)
-            cmd = SiteCommand(args)
-            settings = cmd.settings
-            self.assertEqual(settings.PROJECT_ROOT, root)
-            self.assertEqual(settings.SITE_ROOT, "/")
-            # self.assertEqual(settings.SITE_NAME, "Example web site")
-            self.assertIsNone(settings.SITE_NAME)
-            self.assertEqual(settings.ARCHETYPES, "archetypes")
-            self.assertEqual(settings.CONTENT, "content")
-            self.assertEqual(settings.THEME, "default")
-            self.assertEqual(settings.OUTPUT, "web")
-            self.assertEqual(settings.TIMEZONE, "Europe/Rome")
-            self.assertEqual(settings.SYSTEM_ASSETS, [])
-            self.assertFalse(settings.DRAFT_MODE)
-            self.assertTrue(settings.CACHE_REBUILDS)
+        args = test_utils.Args(project=self.mocksite.root)
+        cmd = SiteCommand(args)
+        settings = cmd.settings
+        self.assertEqual(settings.PROJECT_ROOT, self.mocksite.root)
+        self.assertEqual(settings.SITE_ROOT, "/")
+        # self.assertEqual(settings.SITE_NAME, "Example web site")
+        self.assertIsNone(settings.SITE_NAME)
+        self.assertEqual(settings.ARCHETYPES, "archetypes")
+        self.assertEqual(settings.CONTENT, "content")
+        self.assertEqual(settings.THEME, "default")
+        self.assertEqual(settings.OUTPUT, "web")
+        self.assertEqual(settings.TIMEZONE, "Europe/Rome")
+        self.assertEqual(settings.SYSTEM_ASSETS, [])
+        self.assertFalse(settings.DRAFT_MODE)
+        self.assertTrue(settings.CACHE_REBUILDS)
 
-    def _test_project(self, root, title='Example web site', cfg='', **kw):
-        args = test_utils.Args(project=root + cfg, **kw)
-        build = Build(args)
-        build.settings.THEME_PATHS.insert(0, os.path.join(os.getcwd(), "themes"))
-        build.run()
-
-        output = os.path.join(root, "web/index.html")
+    def test_default_name(self):
+        output = os.path.join(self.build_root, "index.html")
         self.assertTrue(os.path.exists(output))
 
         with open(output, "rt", encoding="utf8") as fd:
@@ -104,20 +102,4 @@ class TestExampleProject(TestCase):
 
         # FIXME: this does not make sense anymore, since title is not defined
         # by settings anymore
-        self.assertIn(title, content)
-
-    def test_default_name(self):
-        with test_utils.example_site_dir() as root:
-            self._test_project(root)
-
-    def test_alt_name(self):
-        with test_utils.example_site_dir() as root:
-            os.rename(os.path.join(root, 'settings.py'),
-                      os.path.join(root, '.staticsite.py'))
-            self._test_project(root)
-
-    def test_custom_name(self):
-        with test_utils.example_site_dir() as root:
-            os.rename(os.path.join(root, 'settings.py'),
-                      os.path.join(root, 'otherconfig.py'))
-            self._test_project(root, cfg='/otherconfig.py')
+        self.assertIn("Example web site", content)
